function [A, pi0, mu, Sigma] = dcv2hmm(AR, AC, V, H, sigma2);

%dcv2hmm   Converts DCV parameters to HMM representation for the H2M toolbox.
%	Use: [A,pi0,mu,Sigma]=dcv2hmm(AR,AC,V,H,sigma2). This function makes
%	it possible to use h2m functions such as hmm_gen, hmm_fb or hmm_vit
%	for real (non complex) convolution models.

% DCV Toolbox, version 1.1
% Olivier Capp, 24/07/97 - 23/12/97
% ENST Dpt. Signal / CNRS URA 820, Paris

% Check input args.
error(nargchk(5, 5, nargin));
[NStat,NSymb,LFilt,REAL_COEFF]=dcv_chk(AR,AC,V,H);

if (REAL_COEFF)
  % Construct transition matrix
  A = zeros(NStat);
  for j = 1:NStat
    A(j, AR(j,:)) = ones(1,NSymb)/NSymb;
  end;
  % Initial probability vector
  pi0 = ones(1,NStat)/NStat;
  % Mean values for each state
  mu = (H'*V)';
  % Covariance is the same for each state
  Sigma = sigma2 * ones(NStat, 1);
else
  error('HMM functions won''t handle complex parameters.');
end;
