function [H, sigma2] = dcv_io (X, v, symb, State1);

%dcv_io    Input-output estimation of the convolution parameters (using
%	   least-squares).
%	Use: [H,sigma2]=dcv_io(X,v,symb,State1), where symb contains the
%	input symbols and State1 is the initial state vector (note that in
%	particular symb(1) = State1(1)).

% DCV Toolbox, version 1.1
% Olivier Capp, 24/12/97 - 24/12/97
% ENST Dpt. Signal / CNRS URA 820, Paris

% Input args.
error(nargchk(4, 4, nargin));
LFilt = length(State1);
T = length(symb);
if (symb(1) ~= State1)
  error('First symbol is also the first element of the initial state vector.');
end;
[AR,AC,V] = dcv_init(v, LFilt);
[NStat,NSymb,LFilt,REAL_COEFF] = dcv_chk(AR,AC,V,zeros(LFilt,1));
symb = [reshape(symb(T:-1:1),T,1); reshape(State1(2:LFilt),LFilt-1,1)];

% Estimate the filter coefficients
S2 = zeros(LFilt, LFilt);
s1 = zeros(LFilt,1);
for t = 1:T
  S2 = S2 + symb(T+1-t:T-t+LFilt)*symb(T+1-t:T-t+LFilt)';
  s1 = s1 + conj(X(t))*symb(T+1-t:T-t+LFilt);
end;
H = S2\s1;
% And the noise variance
sigma2 = real(X'*X - H'*s1)/T;
